@@ -40,7 +40,7 @@
 # Let's start now !
 #
 # You can move your mouse over the
-# "Editor_out" tab on the right
+# "Editor" tab on the right
 # This will show you the first displays
 # that this program has made.
 #
@@ -50,8 +50,33 @@
 # will send you to the line of the file
 # that generated it.
 #
-# The Eval_out will be used later.
+# The "Eval" tab will be used later.
 #
+#    In the same way, when you run a perl
+# program that you are editing,
+# all displays are traced.
+#    To see that, press F5 : a new editor will be
+# created on the right (with the name "demo1").
+# It will contain the displays made by this program 
+# (that has been run by F5) :
+
+print "Hello\n";
+
+say ( "Welcome to Text::Editor::Easy"
+      . "\n"
+      . "introduction" );
+
+sub say {
+    print @_;
+    print STDERR "....",
+    "\n#\n#Writing 'manually' on STDERR...\n";
+}
+
+# Again, if you want to check the origin of these prints, move
+# your mouse over one display with shift key pressed.
+# As you can see, the complete stack call at the time of the print
+# is stored (in your ./tmp directory).
+
 # Now, this demo is finished, you can
 # mouve you mouse over "demo2.pl"
 #
\ No newline at end of file
