@@ -9,11 +9,11 @@ Text::Editor::Easy - A perl module to edit perl code with syntax highlighting an
 
 =head1 VERSION
 
-Version 0.43
+Version 0.44
 
 =cut
 
-our $VERSION = '0.43';
+our $VERSION = '0.44';
 
 =head1 WHY ANOTHER EDITOR ?
 
@@ -81,7 +81,7 @@ Constant re-use is the key to hyper-productivity.
 
 =head1 METHODS
 
-=head2 new
+=head2 NEW
 
     use Text::Editor::Easy;
 
@@ -119,16 +119,23 @@ This function accepts either no parameter or a hash reference which defines the
 If you want to define a special behavior in response to user events you have to write special code and reference this code so that it can be
 executed. You can reference this code during the instance creation.
 
-To have more information about 'Events', look at L<Text::Editor::Easy::Event>.
+To have more information about 'Events', look at L<Text::Editor::Easy::Events>.
 
-=head2 insert
+=head2 INSERT
 
-    $editor->insert("Hello");
+    $editor->insert("Hello");    # Simple insert
+    
+    # Multi-lines insert with list context
     my @lines = $editor->insert("\n\nA non empty line\nAnother non empty line\n\n");
-    my $last_line = $editor->insert("...adding data\nLast line", {
-        'line' => $lines[3],
-        'cursor' => 'at_start',
-    } );
+    
+    # Using options
+    my $last_line = $editor->insert(
+        "...adding data\nLast line",
+        {
+            'line' => $lines[3],
+            'cursor' => 'at_start',
+        }
+    );
 
 The insert method encapsulates horrible code for you (and believe me, my code is terrible !).
 It accepts one or 2 parameters : the first is the string to be inserted, the second, optional, is a hash reference that may change default behavior.
@@ -147,15 +154,23 @@ is changed. You shouldn't use list context for huge string (the 'line' instance
 
 The hash reference, with its options, allows you to modify default behavior :
 
-=over
+=over 4
 
-=item insertion point before the insertion
+=item *
 
-=item how to insert text
+insertion point before the insertion
 
-=item cursor position after the insertion
+=item *
 
-=item how to display things after the insertion
+how to insert text
+
+=item *
+
+cursor position after the insertion
+
+=item *
+
+how to display things after the insertion
 
 =back
 
@@ -168,11 +183,15 @@ As all these things are done implicitly, it seems legitim that options let you d
 By default, the insertion is made at the cursor position. You can change that using 'line' and 'pos' options. The 'line' option must specify
 a valid 'line' instance. The 'pos' option indicates the position of the insertion point in the line. You may use only one of these 2 options :
 
-=over
+=over 4
 
-=item if only the 'pos' option is provided, the line remains the line where the cursor was before insertion : you just change the position in that line.
+=item *
 
-=item if only the 'line' option is provided, the default position is the end of the line you have given.
+if only the 'pos' option is provided, the line remains the line where the cursor was before insertion : you just change the position in that line.
+
+=item *
+
+if only the 'line' option is provided, the default position is the end of the line you have given.
 
 =back
 
@@ -187,7 +206,7 @@ By default, the editor uses the current "insert" config to insert the text. The
 You can force your "insert" config using the 'replace' option. Set to 1 (or true), existing text will be replaced (only in the first line and according
 to the length of your first inserted line too). Set to 0 (or false), text will be inserted.
 
-=head3 cursor position, 'cursor' options
+=head3 cursor position, 'cursor' option
 
 This option tells where to set the cursor after the insertion has been made :
 
@@ -225,14 +244,14 @@ Display option is an integrated call to the display method. As for the 'cursor'
 line that will be used for the display. Otherwise, the syntax is the same as the original display method : as 2 parameters may be provided, the
 'display' option of the insert method is an array reference.
 
-=head3 other option
+=head3 other options
 
 There is an 'assist' option that can call specific sub to make special action each time a particular text have been inserted 
 (typically, adding other text...). But the interface of this option is not yet fixed. In the same way, there will be a way to inhibit the event management
 as, at present, there are 2 events generated by an insert ('change_last' and 'insert_last'). Maybe 'assist' option will be replaced by a generalized
 event management...
 
-=head2 display
+=head2 DISPLAY
 
     $editor->display( 
         $editor->number(23),
@@ -245,8 +264,8 @@ event management...
 The display method needs at least one parameter : the L<'line' instance|Text::Editor::Easy::Line> or L<'display' instance|Text::Editor::Easy::Display>.
 The second, a hash reference, is optionnal.
 
-If your editor is not visible because it's under another one (see L<Text::Editor::Easy::Zone>), you'll make it visible using L</focus> 
-or L</on_top> methods.
+If your editor is not visible because it's under another one (see L<Text::Editor::Easy::Zone>), you'll make it visible using L</FOCUS> 
+or L</ON_TOP> methods.
 The display method is used to show the editor in a precise way. Displaying an editor doesn't mean much if you don't take a reference. The reference
 is the first parameter which is a line or a part of it with wrap mode enabled ('display'). When you have defined this reference, you can add options
 to precise where to put this reference in the screen.
@@ -256,7 +275,7 @@ of the screen height.
 
 You can change where to display the reference line with 'at' and 'from' options.
 
-head3 'at' option
+=head3 'at' option
 
 This option gives the ordinate (which is, by default, one quarter of the screen height). You can use 'top', 'bottom' or 'middle' values or an integer.
 The integer value will position the line precisely in the screen. But you should have receveid the number you give
@@ -267,7 +286,7 @@ will be the line number in console mode (in console mode, you can't be more prec
         $editor->number(23), { 'at' => $my_ordinate } # $my_ordinate should be an integer (or 'bottom', 'middle' or 'top')
     );
 
-head3 'from' option
+=head3 'from' option
 
 As lines have a height, displaying a line at a precise ordinate don't tell what part of the line will be located at this ordinate.
 By default, it's the top of the line. For the 'from' option, you can use 'top', 'middle' and 'bottom'. Note that this option may
@@ -278,12 +297,12 @@ change things a lot if the reference line is a multi-line : wrap mode and severa
 By default, there may be adjustments. If the first line of the editor is under the top, or the last line over the bottom with sufficient lines to fill the screen,
 your precise positioning will be changed. You can avoid adjustments by setting the 'no_check' option to true.
 
-=head2 focus
+=head2 FOCUS
 
 Set the focus to the editor. It will be placed on top of the screen to be visible and will have the 'focus'. Any pressed key will be redirected to it : if
 the cursor belongs to a line that is displayed, it should be visible.
 
-=head2 on_top
+=head2 ON_TOP
 
 Place the editor on top of the screen to make it visible. No action is made if editor was already on top or had the focus.
 
@@ -329,7 +348,8 @@ sub new {
 
     Text::Editor::Easy::Comm::verify_motion_thread( $ref, $hash_ref );
 
-    Text::Editor::Easy::Comm::verify_graphic( $hash_ref, $editor );
+    my $correct = Text::Editor::Easy::Comm::verify_graphic( $hash_ref, $editor );
+    return if ( ! $correct );
 
     #if ( defined $hash_ref->{'growing_file'} ) {
     #    print "GROWING FILE ..$hash_ref->{'growing_file'}\n";
@@ -1130,7 +1150,7 @@ by anybody, including the RAD tool and the applications generated by the RAD too
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 Sebastien Grommier, all rights reserved.
+Copyright 2008 - 2009 Sebastien Grommier, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
